@@ -1,7 +1,4 @@
 import copy
-import logging
-import os.path
-import pickle
 
 import numpy as np
 import scipy.io
@@ -42,18 +39,6 @@ class Lookup:
         self.__default['ID_W'] = None
         self.__default['VDB'] = None
 
-        #['L', 'VGS', 'VDS', 'VSB', 'METHOD']
-
-        #['L', 'VGB', 'GM_ID', 'ID_W', 'VDS', 'VDB', 'VSB', 'METHOD']
-        #default = {'L': min(self['L']),
-        #       'VGB': None,
-        #       'GM_ID': None,
-        #       'ID_W': None,
-        #       'VDS': max(self['VDS'])/2,
-        #       'VDB': None,
-        #       'VSB': 0,
-        #       'METHOD': 'pchip'}
-
     def __load(self, filename):
         """
         Function to load data from file
@@ -179,7 +164,8 @@ class Lookup:
 
         if len(outkeys) > 1:
             num, den = outkeys
-            ydata =  self.__DATA[num]/self.__DATA[den]
+            with np.errstate(divide='ignore',invalid='ignore'):
+                ydata =  self.__DATA[num]/self.__DATA[den]
         else:
             outkey = outkeys[0]
             ydata = self.__DATA[outkey]
@@ -211,13 +197,15 @@ class Lookup:
             output: interpolated data specified by outkeys. Squeezed to remove extra
                     dimensions
         """
-        # unpack outkeys and ydata
-        num, den = outkeys
-        ydata =  self.__DATA[num]/self.__DATA[den]
-        # unpack varkeys and xdata
-        num, den = varkeys
-        xdata = self.__DATA[num]/self.__DATA[den]
-        xdesired = vararg
+        with np.errstate(divide='ignore',invalid='ignore'):    
+            # unpack outkeys and ydata
+            num, den = outkeys
+            ydata =  self.__DATA[num]/self.__DATA[den]
+            # unpack varkeys and xdata
+            num, den = varkeys
+            xdata = self.__DATA[num]/self.__DATA[den]
+        
+        xdesired = np.atleast_1d(vararg)
         
         points = (self.__DATA['L'], self.__DATA['VGS'], self.__DATA['VDS'],\
             self.__DATA['VSB'])
@@ -292,6 +280,7 @@ class Lookup:
         Output:
             output: 1-d numpy array
         """
+        kwargs = {k.upper(): v for k, v in kwargs.items()} # convert kwargs to upper
         defaultdict = {k:self.__default.get(k) for k in ['L', 'VDS', 'VDB', 'VGB', 'GM_ID', 'ID_W', 'VSB', 'METHOD']}
         pars = {k:kwargs.get(k, v) for k,v in defaultdict.items()}
 
