@@ -1,5 +1,6 @@
 from .version import __version__
 from .Lookup import *
+from .Sweep import *
 from .pygmid import main
 
-__all__ = ['main', 'Lookup']
\ No newline at end of file
+__all__ = ['main', 'Lookup', 'Sweep']
\ No newline at end of file
